@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2004-2014 Andrew Mihal
+ * Copyright (C) 2004-2009 Andrew Mihal
+ * Copyright (C) 2009-2015 Christoph Spiel
  *
  * This file is part of Enblend.
  *
@@ -139,10 +140,10 @@ typedef enum
 #define VISUALIZE_STATE_SPACE_UNCONVERGED VISUALIZE_RGB_COLOR_MAGENTA1
 
 
-// For CIECAM blending, Enblend and Enfuse transform the input images
-// from their respective RGB color spaces to XYZ space (and then on to
-// JCh).  The following two #defines control the color transformation
-// from and to XYZ space.
+// For CIELAB, CIELUV, and CIECAM blending, Enblend and Enfuse
+// transform the input images from their respective RGB color spaces
+// to XYZ space (and for CIECAM then on to JCh).  The following two
+// #defines control the color transformation from and to XYZ space.
 #define RENDERING_INTENT_FOR_BLENDING INTENT_PERCEPTUAL
 #define TRANSFORMATION_FLAGS_FOR_BLENDING cmsFLAGS_NOCACHE
 
@@ -255,7 +256,7 @@ strtoken_r(char* str, const char* delim, char** save_ptr)
     {
         char *token = s;
 
-        while (*s != 0 && !strchr(delim, (int) *s))
+        while (*s != 0 && !strchr(delim, static_cast<int>(*s)))
         {
             s++;
         }
@@ -496,6 +497,13 @@ numberOfString(const char* a_string,               // string we want to convert
 }
 
 
+inline bool
+isFloatingPoint(const std::string& aPixelType)
+{
+    return  aPixelType == "FLOAT" || aPixelType == "DOUBLE";
+}
+
+
 /** Convert an anOutputDepth to a "pixel type" string understood by
  * VIGRA. */
 std::string
@@ -749,7 +757,7 @@ expandFilenameTemplate(const std::string& aTemplate,
                     {
                         std::ostringstream oss;
                         oss <<
-                            std::setw(width.empty() ? 1 + ilog10(aNumberOfImages - 1) : atoi(width.c_str())) <<
+                            std::setw(width.empty() ? 1U + ilog10(aNumberOfImages - 1U) : atoi(width.c_str())) <<
                             std::setfill(pad == 0 ? '0' : pad) <<
                             aNumber;
                         result.append(oss.str());
@@ -862,6 +870,16 @@ profileName(cmsHPROFILE profile)
 }
 
 
+inline unsigned
+profileChannels(cmsHPROFILE profile)
+{
+    const cmsColorSpaceSignature signature = cmsGetColorSpace(profile);
+    const unsigned number_of_channels = cmsChannelsOf(signature);
+    assert(number_of_channels == 1U || number_of_channels == 3U);
+    return number_of_channels;
+}
+
+
 namespace parameter
 {
     // Identifier: [A-Za-z][A-Za-z0-9_-]*
