@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2014 Mikolaj Leszczynski
+ * Copyright (C) 2011-2015 Mikolaj Leszczynski
  *
  * This file is part of Enblend.
  *
@@ -34,7 +34,6 @@
 #include <queue>
 
 #include <boost/functional/hash.hpp>
-#include <boost/scoped_ptr.hpp>
 #include <boost/unordered_set.hpp>
 
 #include <vigra/functorexpression.hxx>
@@ -728,7 +727,10 @@ namespace enblend {
              ++currentDual) {
 
             current = convertFromDual(*currentDual);
-            next = convertFromDual(*nextDual);
+
+            if (nextDual != cut->end()) {
+                next = convertFromDual(*nextDual);
+            }
 
             if (currentDual == cut->begin()) {
                 ++nextDual;
@@ -1301,7 +1303,6 @@ namespace enblend {
         typedef vigra::UInt8 BasePixelType;
         typedef float GradientPixelType;
         typedef vigra::NumericTraits<BasePixelType> BasePixelTraits;
-        typedef vigra::NumericTraits<GradientPixelType> GradientPixelTraits;
         typedef typename BasePixelTraits::Promote BasePromotePixelType;
         typedef vigra::NumericTraits<BasePromotePixelType> BasePromotePixelTraits;
         typedef typename BasePromotePixelTraits::Promote GraphPixelType;
@@ -1323,7 +1324,7 @@ namespace enblend {
         std::vector<vigra::Point2D>* dualPath = NULL;
         std::vector<vigra::Point2D> totalDualPath;
         vigra::Point2D intermediatePoint;
-        boost::scoped_ptr<CheckpointPixels> srcDestPoints(new CheckpointPixels());
+        CheckpointPixels srcDestPoints;
 
         const vigra::Diff2D graphsize(graphImg.lowerRight().x - graphImg.upperLeft().x,
                                graphImg.lowerRight().y - graphImg.upperLeft().y);
@@ -1432,9 +1433,9 @@ namespace enblend {
                 continue;
             }
 
-            srcDestPoints->clear();
-            srcDestPoints->top.insert(intermediatePoint);
-            srcDestPoints->bottom.insert(*i);
+            srcDestPoints.clear();
+            srcDestPoints.top.insert(intermediatePoint);
+            srcDestPoints.bottom.insert(*i);
 
 #ifdef DEBUG_GRAPHCUT
             std::cout << "Running graph-cut: " << intermediatePoint << ":" << *i << std::endl;
@@ -1442,7 +1443,7 @@ namespace enblend {
 
             dualPath = A_star<IMAGETYPE<GraphPixelType>, IMAGETYPE<GradientPixelType>, BasePixelType>
                 (vigra::Point2D(-10, -10), vigra::Point2D(-20, -20), &intermediateGraphImg, &gradientX,
-                 &gradientY, graphsize - vigra::Diff2D(1, 1), srcDestPoints.get(), &visited);
+                 &gradientY, graphsize - vigra::Diff2D(1, 1), &srcDestPoints, &visited);
 
             visited.insert(dualPath->begin(), dualPath->end());
 
