@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2014 Mikolaj Leszczynski
+ * Copyright (C) 2011-2015 Mikolaj Leszczynski
  *
  * This file is part of Enblend.
  *
@@ -284,8 +284,8 @@ namespace enblend
 
                         if (currentVertex->first || nextVertex->first) {
                             // Find shortest path between these points
-                            vigra::Point2D currentPoint = currentVertex->second;
-                            vigra::Point2D nextPoint = nextVertex->second;
+                            const vigra::Point2D currentPoint = currentVertex->second;
+                            const vigra::Point2D nextPoint = nextVertex->second;
 
                             vigra::Rect2D pointSurround(currentPoint, vigra::Size2D(1, 1));
                             pointSurround |= vigra::Rect2D(nextPoint, vigra::Size2D(1, 1));
@@ -303,11 +303,18 @@ namespace enblend
                                             vigra::Point2D(nextPoint - pointSurround.upperLeft()),
                                             vigra::Point2D(currentPoint - pointSurround.upperLeft()));
 
+                            if (shortPath->empty()) {
+                                std::cerr << command << ": warning: unable to run Dijkstra optimizer\n"
+                                          << command << ": info: seam-line end point outside of cost-image"
+                                          << std::endl;
+                            }
+
                             for (std::vector<vigra::Point2D>::iterator shortPathPoint = shortPath->begin();
                                  shortPathPoint != shortPath->end();
                                  ++shortPathPoint) {
                                 snake->insert(enblend::next(currentVertex),
-                                              std::make_pair(false, *shortPathPoint + pointSurround.upperLeft()));
+                                              std::make_pair(false,
+                                                             *shortPathPoint + pointSurround.upperLeft()));
 
                                 if (this->visualizeImage) {
                                     (*this->visualizeImage)[*shortPathPoint + pointSurround.upperLeft()] =
@@ -318,14 +325,21 @@ namespace enblend
                             delete shortPath;
 
                             if (this->visualizeImage) {
-                                (*this->visualizeImage)[currentPoint] =
-                                    currentVertex->first ?
-                                    VISUALIZE_FIRST_VERTEX_VALUE :
-                                    VISUALIZE_NEXT_VERTEX_VALUE;
-                                (*this->visualizeImage)[nextPoint] =
-                                    nextVertex->first ?
-                                    VISUALIZE_FIRST_VERTEX_VALUE :
-                                    VISUALIZE_NEXT_VERTEX_VALUE;
+                                const vigra::Size2D size(*this->visualizeImage->size());
+                                const vigra::Rect2D valid_region(size);
+
+                                if (valid_region.contains(currentPoint)) {
+                                    (*this->visualizeImage)[currentPoint] =
+                                        currentVertex->first ?
+                                        VISUALIZE_FIRST_VERTEX_VALUE :
+                                        VISUALIZE_NEXT_VERTEX_VALUE;
+                                }
+                                if (valid_region.contains(nextPoint)) {
+                                    (*this->visualizeImage)[nextPoint] =
+                                        nextVertex->first ?
+                                        VISUALIZE_FIRST_VERTEX_VALUE :
+                                        VISUALIZE_NEXT_VERTEX_VALUE;
+                                }
                             }
                         }
 
